==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BIOSFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class BIOSFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSFluent<A>{
  public BIOSFluentImpl() {
  }
  public BIOSFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS instance) {
    this.withDate(instance.getDate()); 
    this.withVendor(instance.getVendor()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String date;
  private java.lang.String vendor;
  private java.lang.String version;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDate() {
    return this.date;
  }
  public A withDate(java.lang.String date) {
    this.date=date; return (A) this;
  }
  public java.lang.Boolean hasDate() {
    return this.date != null;
  }
  
  /**
   * Method is deprecated. use withDate instead.
   */
  @java.lang.Deprecated
  public A withNewDate(java.lang.String arg0) {
    return (A)withDate(new String(arg0));
  }
  public java.lang.String getVendor() {
    return this.vendor;
  }
  public A withVendor(java.lang.String vendor) {
    this.vendor=vendor; return (A) this;
  }
  public java.lang.Boolean hasVendor() {
    return this.vendor != null;
  }
  
  /**
   * Method is deprecated. use withVendor instead.
   */
  @java.lang.Deprecated
  public A withNewVendor(java.lang.String arg0) {
    return (A)withVendor(new String(arg0));
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public A withVersion(java.lang.String version) {
    this.version=version; return (A) this;
  }
  public java.lang.Boolean hasVersion() {
    return this.version != null;
  }
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0) {
    return (A)withVersion(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BIOSFluentImpl that = (BIOSFluentImpl) o;
    if (date != null ? !date.equals(that.date) :that.date != null) return false;
    if (vendor != null ? !vendor.equals(that.vendor) :that.vendor != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(date,  vendor,  version,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BIOSFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class BIOSFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSFluent<A>{
  public BIOSFluentImpl() {
  }
  public BIOSFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS instance) {
    this.withDate(instance.getDate()); 
    this.withVendor(instance.getVendor()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String date;
  private java.lang.String vendor;
  private java.lang.String version;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDate() {
    return this.date;
  }
  public A withDate(java.lang.String date) {
    this.date=date; return (A) this;
  }
  public java.lang.Boolean hasDate() {
    return this.date != null;
  }
  
  /**
   * Method is deprecated. use withDate instead.
   */
  @java.lang.Deprecated
  public A withNewDate(java.lang.String arg0) {
    return (A)withDate(new String(arg0));
  }
  public java.lang.String getVendor() {
    return this.vendor;
  }
  public A withVendor(java.lang.String vendor) {
    this.vendor=vendor; return (A) this;
  }
  public java.lang.Boolean hasVendor() {
    return this.vendor != null;
  }
  
  /**
   * Method is deprecated. use withVendor instead.
   */
  @java.lang.Deprecated
  public A withNewVendor(java.lang.String arg0) {
    return (A)withVendor(new String(arg0));
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public A withVersion(java.lang.String version) {
    this.version=version; return (A) this;
  }
  public java.lang.Boolean hasVersion() {
    return this.version != null;
  }
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0) {
    return (A)withVersion(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BIOSFluentImpl that = (BIOSFluentImpl) o;
    if (date != null ? !date.equals(that.date) :that.date != null) return false;
    if (vendor != null ? !vendor.equals(that.vendor) :that.vendor != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(date,  vendor,  version,  additionalProperties,  super.hashCode());
  }
  
}
